Paxtor.Spawn (paxtor v0.3.0)
A via registry module for temporary singleton processes.
Summary
Functions
Returns a :via tuple that can be used to spawn or access the singleton process.
A via registry module for temporary singleton processes.
Returns a :via tuple that can be used to spawn or access the singleton process.